The Administrative Court is a specialist court within the King’s Bench Division of the High Court. It specialises in public law, often reviewing the decisions made by local authorities and regulatory bodies in England and Wales. The Administrative Court contains a dedicated Planning Court for planning related disputes. Cases in the Administrative Court may be heard by a Divisional Court, which is a court consisting of at least two judges.

This court began to regularly transfer judgments to The National Archives in 2022. The oldest judgment from this court included in Find Case Law is from {start_year}.

You can read more about [the Administrative court on the judiciary website](https://www.judiciary.uk/courts-and-tribunals/high-court/administrative-court/){target="\_blank"}.
